<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>Chyba v config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>Chyba v běžícím pluginu:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>Nepodařilo se nahrát soubor.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>Špatný formát souboru.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>Nepodařilo se uložit soubor.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>Nepodařilo se parsovat XML:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>Neznámé kódování.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>Chybí odpověď na řádku:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>Nepodařilo se nahrát databázi.
Vytvářím tmp soubor.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>Soubor existuje:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;Přepsat</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>Odebrané duplicitní kartičky: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>Existují karty s různými odpověďmi na otázku:</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Sloučit a editovat</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;Neslučovat</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>Hotovo!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation>Tuto kartu jste si zatím nezapamatoval(a).</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation>Jako &apos;0&apos;, ale už vám to připadá povědomé.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation>Neukazovat tak často.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation>Tuto kartu jste si právě zapamatoval(a)</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation> a pravděpodobně si ji několik dnů budete pamatovat.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation>Tuto kartu jste kompletně zapomněl(a).</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation>Téměř správná odpověď. Interval byl příliš dlouhý.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation>Správná odpověď, ale s velkým úsilím.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation> Interval byl pravděpodobně moc dlouhý.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation>Správná odpověď, i když s určitým úsilím.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation> Interval byl pravděpodobně odpovídající.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation>Správná odpověď bez jakýchkoliv</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation> potíží. Interval byl pravděpodobně moc krátký.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Hlavní autor: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">Více informací: http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>Více informací: http://mnemosyne-proj.org
</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Aktivovat kategorie</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Vyberte, které kategorie aktivovat:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Neaktivovat žádné</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Aktivovat všechny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Zahodit tuto kartu?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Psaná forma:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Překlad:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Karta již je v databázi.</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Duplikát nebyl přidán.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Existují různé odpovědi na</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> tuto otázku:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Sloučit a editovat</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Přidat jak je</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Nepřidávat</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Přidat karty</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Výslovnost:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Přidat i &amp;obráceně (odpověď -&gt; otázka)</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Vyberte počáteční stupeň:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Tuto položku jste si ještě nezapamatoval(a) nebo zapomněl(a).</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Jako &apos;0&apos;, ale už vám to připadá povědomé.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Tuto kartu jste si právě zapamatoval(a) a pravděpodobně si ji několik dnů budete pamatovat.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Správná odpověď, ale s velkým úsilím. Interval byl pravděpodobně moc dlouhý</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Správná odpověď, i když s určitým úsilím. Interval byl pravděpodobně akorát.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Správná odpověď bez jakýchkoliv potíží. Interval byl pravděpodobně moc krátký.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Napište otázku a odpověď a zvolte počáteční stupeň.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Náhled</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Konec</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Změnit kategorii</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Nastavení Mnemosyne</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Pro získání dalších informací najeďte myší nad tlačítka.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Nastavit Q/A fonty</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Nastavení fontu použitého při zobrazení jednotlivých otázek a odpovědí</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Nastavení fontu seznamu</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Nastavení fontu použitého při zobrazení seznamu všech karet</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Zvětšit velikost ne-latin znaků o</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Při původní velikosti latin fontu se komplexní glyfy někdy špatně čtou</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>bod(ů)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Posílání logů</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Posílat anonymní logy</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Sdílet anonymní statistiky a tím přispívat na výzkum paměti</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Zacházení s duplicitními kartičkami</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Kontrolovat duplikáty při přidávání nových kartiček</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Povolit duplicitní kartičky v různých kategoriích</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Proces opakování</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">Počet karet s hodnocením 0 pro okamžité učení:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Pozn.: toto NENÍ počet karet se hodnocením 0, které se chcete naučit *za den*</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Původní</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation>Učit se nové kartičky v náhodném pořadí</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Editovat kartu</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Náhled</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Čekejte prosím...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editovat</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Náhled</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;Přidat i opak</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>S&amp;tatistika</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;Změnit kategorii</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Přidat i &amp;opak</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Přidat opak těchto karet?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Přidat opak této karty?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Tímto se mohou vytvořit duplikáty pokud </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>již existují opaky,
takže by jste potom měl(a) provést </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>&apos;Odstranit duplicitní kartičky&apos;.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Hodnocení:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Jednoduchost:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Opakování:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Zapomenutí:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Dnů od posledního opakování:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dnů do dalšího opakování:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Smazat tyto karty?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Smazat tuto kartu?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>Vložený text nebyl nalezen.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Hledat znovu</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Hledat</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Odpověď</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Editovat karty</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Najít</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Pro editaci karty použijte pravé tlačítko myši.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Konec</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation>Alt+F</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Všechny soubory (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Export do souboru</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Formát souboru:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Exportovat do souboru:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Procházet</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Exportovat kategorie:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Vybrat vše</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Resetovat učební proces při exportu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Všechny soubory (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Import ze souboru</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Formát souboru:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Importovat ze souboru:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Procházet</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Karty bez kategorie vložit do kategorie:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Pozn.: všechny karty budou přidány do současné databáze.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Resetovat učební proces při importu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Mnemosyne databáze (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Čekejte prosím...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>Smazat tuto kartu?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>Ukáže se za </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation> dnů.</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>Další opakování: dnes.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>Další opakování: zítra.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>Další opakování za </translation>
    </message>
    <message>
        <source> days.</source>
        <translation> dnů.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">Ukázat &amp;odpověď</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>Učit se navíc</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>Vyberte počet dnů do dalšího opakování:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Ohodnoťte svou odpověď:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>Naplánovaných: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>Nezapamatovaných: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation>Všech: </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Ukázat odpověď</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Ukázat odpověď</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Ohodnoťte svou odpověď:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nová</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Uložit j&amp;ako</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Konec</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Přidat karty</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>Přid&amp;at karty</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Act&amp;ivate categories</source>
        <translation type="obsolete">Akt&amp;ivovat kategorie</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Editovat karty</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>E&amp;ditovat karty</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importovat</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportovat</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Zobrazovat nástrojovou lištu</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Editovat tuto kartu</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Editovat tuto kartu</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Smazat tuto kartu</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Smazat tuto kartu</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Odstranit duplicitní kartičky</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Konfigurovat Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Jak začít</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Jak začít</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Dolů, Dolů</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Ukázat statistiky</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Ukázat s&amp;tatistiky</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Tip dne</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Tip dne</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Hlavní nástrojová lišta (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Databáze</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Karty</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Akt&amp;ivovat kategorie</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Předchozí karta</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Otázka:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Jak začít</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Ahojky!

Já jsem Mnemosyne, druh motýla pojmenovaný po řecké bohyni paměti.

Můžu vám pomoct si zapamatovat odpovědi na otázky tím, že se zaměříme na karty s otázkami, které zapomínáte a nebudeme tak plýtvat časem na věci, které znáte dobře.

Já rozhodnu, kdy se vás budu ptát na otázky a vy potom ohodnotíte, jak dobře si pamatujete odpovědi.

Teď se podíváme na možnosti hodnocení.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Úvod</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Rozsah hodnocení je od 0 do 5.

Hodnocení 0 a 1 použijte pokud neznáte odpověď nebo jste ji zapomněli. Karta s hodnocením 1 vám připadá povědomější než karta s ohodnocením 0 a proto nebude opakována tak často.

Tyto (vámi ohodnocené jako 0 nebo 1) karty vám budu ukazovat tak dlouho, dokud jim nedáte hodnocení 2 nebo vyšší. Hodnocení 2 v podstatě znamená, že si myslíte, že si dokážete tuto kartu alespoň na den či dva zapamatovat. To signalizuje přechod mezi krátkodobou a dlouhodobou pamětí.

Já potom tuto kartu naplánuji na určité datum v budoucnu, kdy si myslím, že si ji stále ještě dokážete s určitým úsilím vybavit (ještě na ni úplně nezapomenete). Toto je pro učební proces velmi důležité.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Hodnocení 0 až 2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Pokud vám v budoucnu položím otázku příliš brzo a vy na ni dokážete bez jakýchkoliv potíží odpovědět, dejte kartě hodnocení 5. Já to vezmu v potaz a příště počkám mnohem déle, než vám tuto otázku znovu položím.

Pokud se trefím do správného okamžiku a vy dokážete na otázku správně odpovědět i když s určitým úsilím, dejte kartě hodnocení 4.

Pokud vám to dá pořádně zabrat než si vybavíte odpověď a myslíte si, že jsem s položením otázky čekal příliš dlouho, dejte kartě hodnocení 3.

Pokud si nemůžete vzpomenout vůbec, ohodnoťte ji 0 nebo 1 a já se vás na ni budu ptát tak dlouho, dokud si nebudete myslet, že si ji opět dokážete na několik dnů zapamatovat.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Hodnocení 3 až 5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Pokud máte zájem o statistiky, je možné udržovat podrobné záznamy učebního procesu.

Krom toho můžu uploadovat kompletně anonymní verze těchto záznamů  na centrální stránky, takže mi pomůžete mě vylepšovat. Tím také přispějete k vědeckému výzkumu dlouhodobé paměti.

Odznačte následující rámeček, pokud nemáte zájem o výše uvedené možnosti.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Uploadovat anonymní logy</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Toto nastavení můžete kdykoliv později změnit v menu v &apos;Konfigurovat Mnemosyne&apos;)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiky</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Nyní jste připraveni začít!
&lt;p&gt;
Nové karty přidáte kliknutím na ikonu vlevo nahoře (se znakem &apos;plus&apos;). 
&lt;p&gt;
O ukládání vaší práce se starat nemusíte, to já budu dělat automaticky.
&lt;p&gt;
Nejlepších výsledků dosáhnete, pokud budete opakovat každý den. Budu ale dělat, co je v mých silách i pokud opakování odložíte nebo se rozhodnete naučit se něco navíc.
&lt;p&gt;
Další dokumentace viz. http://mnemosyne-proj.org
&lt;p&gt;
Šťastné učení!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Připraveni začít</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Vlož&amp;it obrázek</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Vložit &amp;zvuk</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;3-stranná karta (zápis, výslovnost, překlad)</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Soubory s obrázky</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Vložit obrázek</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Soubory se zvuky</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Vložit zvuk</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">Karty naplánované na následující dny:
        
</translation>
    </message>
    <message>
        <source>In</source>
        <translation>Za</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>den(dnů) :</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Počty karet s danými hodnoceními:
        
</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Hodnocení</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation>Není žádná aktuální karta</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Hodnocení:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Jednoduchost:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Opakování:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Zapomenutí:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Dnů od posledního opakování:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dnů do dalšího opakování:</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Karty</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiky</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Rozvrh</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Hodnocení</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation>Aktuální karta</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>Pro optimální výsledky je nejlepší opakovat každý den.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Pokud jste několik dnů vynechali, nemějte strach z nahromaděných nedodělků. Udělejte tolik karet, na kolik se cítíte a zbytek bude automaticky přeplánován do budoucna.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>Nastavení &apos;Počet karet s hodnocením 0 pro okamžité učení&apos; udává kolik neprobraných karet se budete učit najednou. Rozhodně &lt;b&gt;ne&lt;/b&gt;určuje kolik nových karet se máte naučit za den. To si rozhodnete sami: můžete se naučit více nebo méně, záleží na Vás.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Pokuste se opakovat každý den. Není ale vždy nutné dostat čítač &apos;naplánovaných&apos; karet na nulu a už vůbec ne čítač &apos;nezapamatovaných&apos; karet.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Karty s hodnocením 1 se liší od karet s hodnocením 0 v tom smyslu, že se nezobrazují tak často a také se s nimi nepočítá v nastavení &apos;Počet karet s hodnocením 0 pro okamžité učení&apos;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>K opakování můžete používat klávesové zkratky: Enter ukáže odpověď a mezerník ohodnotí kartu stupněm 4. Hodnotit lze i numerickými klávesami.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Kategorie, které chcete studovat je možné vybrat v menu v &apos;Aktivovat kategorie&apos;.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Je doporučeno dávat všechny karty do jedné databáze a k jejich organizaci používat kategorie. Použití možnosti &apos;Aktivovat kategorie&apos; je pohodlnější, než nahrávání různých databází.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Je možné importovat karty různých formátů: txt soubory s hesly oddělenými tabulátorem, soubory ve formátu programu Supermemo, aj.</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Jestliže máte kartičky ve Wordu nebo Excelu a chcete je importovat do Mnemosyne, tak je exportujte do txt souboru s hesly oddělenými tabulátorem a UTF-8 kódováním.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Pokud chcete vaše kartičky vytisknout, exportujte je do txt souboru, který pak můžete vytisknout.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Pokud chcete sdílet s někým své kartičky, exportujte je do XML (současně vyberte možnost &apos;Resetovat učební proces&apos;).</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Pokud studujete cizí jazyk s jiným písmem, může být přednastavená velikost fontu menší. Jestliže chcete zvětšit velikost těchto znaků, ale ponechat velikost textu ve vašem jazyce, použijte možnost &apos;Zvětšit velikost ne-latin znaků o X bodů&apos;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Do karet je možné přidávat také obrázky a zvuky. Během editace nebo při přidávání karty, klikněte v editačním okně karty pravým tlačítkem myši na pole s otázkou nebo odpovědí a v menu vyberte jednu z možností.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Doporučuje se nechávat soubory s obrázky a zvuky uvnitř vašeho .mnemosyne adresáře (adresář, kde jsou uloženy databáze). Snadněji se vám pak budou přenášet data mezi počítači.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Při přidávání karty můžete zvolit 3-strannou kartu (psaná forma, výslovnost, překlad) a to tak, že kliknete pravým tlačítkem myši na pole s otázkou a vyberete možnost &apos;3-stranná karta&apos;. Když přidáváte kartu se 3 stranami, budou vytvořeny a přidány dvě karty. V první kartě bude v otázce zápis (slovíčka) a v odpovědi výslovnost a překlad. V druhé kartě bude v otázce překlad a v odpovědi zápis a výslovnost.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>V kartičkách můžete pro upravování vzhledu používat HTML tagy.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne umí používat LaTeX k vytváření matematických vzorců, např. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (K tomu ale ještě musíte mít nainstalován LaTeX a dvipng.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>Nejlepší cestou k zálohování vašich dat je kopírovat váš .mnemosyne adresář (za předpokladu, že se držíte doporučení a máte všechny soubory v tomto adresáři) na jiný disk. Mnemosyne sice automaticky vytváří XML zálohy v .mnemosyne/backups, to vám ale při poruše disku nebude moc platné. </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Mnemosyne je možné mít a spouštět z USB klíčenky. Stačí zkopírovat adresář C:\Program Files\Mnemosyne na klíčenku a do něj adresář .mnemosyne z vašeho domovského adresáře.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Pokud používáte Mnemosyne na více počítačích, může se vám hodit nástroj Unison, který je určený pro synchronizaci vašich dat. Více informací najdete na stránkách Mnemosyne (nebo na http://www.cis.upenn.edu/~bcpierce/unison).</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>V menu v &apos;Editovat karty&apos; můžete karty třídit podle odpovědi nebo podle kategorie tak, že kliknete na příslušný nadpis sloupce.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Více informací o LaTeXu v Mnemosyne najdete na www stránkách Mnemosyne.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Pokročilí uživatelé si mohou nastavit Mnemosyne editací souboru config.py v .mnemosyne adresáři. Je možné také instalovat pluginy, které dále mění chování Mnemosyne.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Tip dne</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Věděli jste, že ...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>Ukazovat tipy při &amp;startu</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Předchozí</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Další</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
